/**
 * Copyright (C) 2001 Billy Biggs.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef SCREEN_H_INCLUDED
#define SCREEN_H_INCLUDED

#include <song.h>

class PatBar;
class ChanBar;
class SongBar;

class ModeState
{
public:
	ModeState( void ) : cursorrow( 0 ), scrolltop( 0 ) {}
	int cursorrow;
	int scrolltop;
};

class Screen
{
public:
	Screen( void );
	~Screen( void );

	bool pollScreen( void );
	void refresh( void ) const;
	void showStatusMessage( char *newmsg ) const;

private:
	ChanBar **bars;
	PatBar **patbars;
	SongBar **songbars;
	int pos;
	int octave;
	bool intsync;
	bool patmode;
	int curcol;
	ModeState curstate;
	ModeState patstate;
	ModeState songstate;
	SongPattern copyPattern;

	void switchMode( void );
	void printHeader( void ) const;
	void printSidebar( void ) const;
	void printHelp( void ) const;

	void setNote( int newnote );
	void moveCursorPosition( int newrow, int newcol );
	void setPosition( int newpos );
	void inputTempo( void ) const;
	void saveSong( void ) const;
	void loadSong( void ) const;
	void toggleSync( void );
	void saveCopy( void );
	void pasteCopy( void );
	void enterPatName( void ) const;
	void enterChanName( void ) const;
};

#endif // SCREEN_H_INCLUDED
