/**
 * Copyright (C) 2001 Billy Biggs.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <pwd.h>
#include <sys/types.h>
#include <unistd.h>
#include <utils.h>
#include <string.h>
#include <sched.h>

// Modified from the UNIX FAQ.  Google gave me this URL:
// http://www.erlenstar.demon.co.uk/unix/faq_3.html

string expand_path( const string &path )
{
	if( path.length() == 0 || path[ 0 ] != '~' )
		return path;

	const char *pfx = NULL;
	string::size_type pos = path.find_first_of( '/' );

	if( path.length() == 1 || pos == 1 ) {
		pfx = getenv( "HOME" );

		if( !pfx ) {
			// Punt. We're trying to expand ~/, but HOME
			// isn't set.
			struct passwd *pw = getpwuid( getuid() );
			if( pw ) pfx = pw->pw_dir;
		}
	} else {
		string user( path, 1, ( pos == string::npos ) ? string::npos : pos - 1 );
		struct passwd *pw = getpwnam( user.c_str() );
		if( pw ) pfx = pw->pw_dir;
	}

	// If we failed to find an expansion, return the path unchanged.
	if( !pfx ) return path;

	string result( pfx );

	if( pos == string::npos ) return result;

	if( result.length() == 0 || result[ result.length() - 1 ] != '/' )
		result += '/';

	result += path.substr(pos+1);

	return result;
}

int set_realtime_priority( void )
{
	struct sched_param schp;

	memset( &schp, 0, sizeof( schp ) );
	schp.sched_priority = sched_get_priority_max( SCHED_FIFO );

	if( sched_setscheduler( 0, SCHED_FIFO, &schp ) != 0 ) {
		return -1;
	}

	return 0;
}

